/* libmondo-archive-EXT.h */


extern int archive_this_fileset(char *filelist, char *fname, int setno);
extern int backup_data();
extern int call_mindi_to_supply_boot_disks();
extern bool can_we_fit_these_files_on_media(
											char *files_to_add, ...);
extern int do_that_initial_phase();
extern int do_that_final_phase();
extern int figure_out_kernel_path_interactively_if_necessary(char *kernel);
extern int make_those_slices_phase();
extern int make_those_afios_phase();
extern int make_slices_and_images(
								  char *biggielist_fname);
extern int make_iso_fs(char *destfile);
extern int make_afioballs_and_images();
extern int (*move_files_to_cd) (char *, ...);
extern int _move_files_to_cd(char *, ...);
extern int (*move_files_to_stream) (char *, ...);
extern int _move_files_to_stream(
								 char *files_to_add, ...);
extern void pause_and_ask_for_cdr(int, bool *);
extern int slice_up_file_etc(
							 char *biggie_filename,
							 char *ntfsprog_fifo,
							 long biggie_file_number,
							 long noof_biggie_files,
							 bool use_ntfsprog);
extern int verify_data();
extern void wipe_archives(char *d);
extern int write_iso_and_go_on(bool last_cd);
extern int write_final_iso_if_necessary();
extern int call_growisofs(char *destfile);
extern int make_afioballs_and_images_SINGLETHREAD();
extern void setenv_mondo_share(void);
